Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/isl29125_simpletest.py
    :caption: examples/isl29125_simpletest.py
    :linenos:

Operation Mode
--------------

Example showing how to change the sensor operation mode

.. literalinclude:: ../examples/isl29125_operation_mode.py
    :caption: examples/isl29125_operation_mode.py
    :linenos:

RGB Sensing Range
------------------

Example showing how to change the sensor RGB sensing range

.. literalinclude:: ../examples/isl29125_rgb_sensing_range.py
    :caption: examples/isl29125_rgb_sensing_range.py
    :linenos:

ADC Resolution
------------------

Example showing how to change the sensor ADC Resolution

.. literalinclude:: ../examples/isl29125_rgb_sensing_range.py
    :caption: examples/isl29125_rgb_sensing_range.py
    :linenos:
